enabled integer intrinsics tests

Change-Id: I5d28d556f228240eda2fc0098121ed3b29b041e7
This commit is contained in:
Aditya Atluri
2017-01-17 09:59:08 -06:00
parent 02c7f3a70f
commit 13ce9ece77
3 changed files with 29 additions and 26 deletions
+12 -12
View File
@@ -1,5 +1,5 @@
/*
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2015-2017 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
@@ -30,27 +30,27 @@ __device__ void integer_intrinsics()
{
__brev((unsigned int)10);
__brevll((unsigned long long)10);
//__byte_perm((unsigned int)0, (unsigned int)0, 0);
__byte_perm((unsigned int)0, (unsigned int)0, 0);
__clz((int)10);
__clzll((long long)10);
__ffs((int)10);
__ffsll((long long)10);
//__hadd((int)1, (int)3);
__hadd((int)1, (int)3);
__mul24((int)1, (int)2);
//__mul64hi((long long)1, (long long)2);
//__mulhi((int)1, (int)2);
__mul64hi((long long)1, (long long)2);
__mulhi((int)1, (int)2);
__popc((unsigned int)4);
__popcll((unsigned long long)4);
int a = min((int)4, (int)5);
int b = max((int)4, (int)5);
//__rhadd((int)1, (int)2);
//__sad((int)1, (int)2, 0);
//__uhadd((unsigned int)1, (unsigned int)3);
__rhadd((int)1, (int)2);
__sad((int)1, (int)2, 0);
__uhadd((unsigned int)1, (unsigned int)3);
__umul24((unsigned int)1, (unsigned int)2);
//__umul64hi((unsigned long long)1, (unsigned long long)2);
//__umulhi((unsigned int)1, (unsigned int)2);
//__urhadd((unsigned int)1, (unsigned int)2);
//__usad((unsigned int)1, (unsigned int)2, 0);
__umul64hi((unsigned long long)1, (unsigned long long)2);
__umulhi((unsigned int)1, (unsigned int)2);
__urhadd((unsigned int)1, (unsigned int)2);
__usad((unsigned int)1, (unsigned int)2, 0);
}
__global__ void compileIntegerIntrinsics(hipLaunchParm lp, int ignored)